@@ -1,34 +1,45 @@
-from alembic.ddl.impl import DefaultImpl
-from alembic.ddl.base import ColumnNullable, ColumnName, ColumnDefault, ColumnType, AlterColumn
 from sqlalchemy.ext.compiler import compiles
-from alembic.ddl.base import alter_table
-from alembic import util
 from sqlalchemy import types as sqltypes
 from sqlalchemy import schema
 
+from ..compat import string_types
+from .. import util
+from .impl import DefaultImpl
+from .base import ColumnNullable, ColumnName, ColumnDefault, \
+            ColumnType, AlterColumn, format_column_name
+from .base import alter_table
+
 class MySQLImpl(DefaultImpl):
     __dialect__ = 'mysql'
 
+    transactional_ddl = False
+
     def alter_column(self, table_name, column_name,
                         nullable=None,
                         server_default=False,
                         name=None,
                         type_=None,
                         schema=None,
+                        autoincrement=None,
                         existing_type=None,
                         existing_server_default=None,
-                        existing_nullable=None
+                        existing_nullable=None,
+                        existing_autoincrement=None
                     ):
         self._exec(
             MySQLAlterColumn(
                 table_name, column_name,
                 schema=schema,
                 newname=name if name is not None else column_name,
-                nullable =nullable if nullable is not None else
-                                existing_nullable if existing_nullable is not None
+                nullable=nullable if nullable is not None else
+                                existing_nullable
+                                if existing_nullable is not None
                                 else True,
                 type_=type_ if type_ is not None else existing_type,
-                default=server_default if server_default is not False else existing_server_default,
+                default=server_default if server_default is not False
+                                            else existing_server_default,
+                autoincrement=autoincrement if autoincrement is not None
+                                            else existing_autoincrement
             )
         )
 
@@ -37,12 +48,14 @@ class MySQLAlterColumn(AlterColumn):
                         newname=None,
                         type_=None,
                         nullable=None,
-                        default=False):
+                        default=False,
+                        autoincrement=None):
         super(AlterColumn, self).__init__(name, schema=schema)
         self.column_name = column_name
         self.nullable = nullable
         self.newname = newname
         self.default = default
+        self.autoincrement = autoincrement
         if type_ is None:
             raise util.CommandError(
                 "All MySQL ALTER COLUMN operations "
@@ -65,24 +78,34 @@ def _mysql_doesnt_support_individual(element, compiler, **kw):
 def _mysql_alter_column(element, compiler, **kw):
     return "%s CHANGE %s %s" % (
         alter_table(compiler, element.table_name, element.schema),
-        element.column_name,
+        format_column_name(compiler, element.column_name),
         _mysql_colspec(
             compiler,
             name=element.newname,
             nullable=element.nullable,
             server_default=element.default,
-            type_=element.type_
+            type_=element.type_,
+            autoincrement=element.autoincrement
         ),
     )
 
-def _mysql_colspec(compiler, name, nullable, server_default, type_):
+def _render_value(compiler, expr):
+    if isinstance(expr, string_types):
+        return "'%s'" % expr
+    else:
+        return compiler.sql_compiler.process(expr)
+
+def _mysql_colspec(compiler, name, nullable, server_default, type_,
+                                        autoincrement):
     spec = "%s %s %s" % (
-        name,
+        format_column_name(compiler, name),
         compiler.dialect.type_compiler.process(type_),
         "NULL" if nullable else "NOT NULL"
     )
-    if server_default:
-        spec += " DEFAULT '%s'" % server_default
+    if autoincrement:
+        spec += " AUTO_INCREMENT"
+    if server_default != False:
+        spec += " DEFAULT %s" % _render_value(compiler, server_default)
 
     return spec
 
