@@ -10,7 +10,7 @@ from mako.template import Template
 from sqlalchemy.engine import url
 from sqlalchemy import __version__
 
-from .compat import callable, exec_, load_module
+from .compat import callable, exec_, load_module, binary_type
 
 class CommandError(Exception):
     pass
@@ -30,10 +30,17 @@ if not sqla_07:
 from sqlalchemy.util import format_argspec_plus, update_wrapper
 from sqlalchemy.util.compat import inspect_getfullargspec
 
+
 try:
-    width = int(os.environ['COLUMNS'])
-except (KeyError, ValueError):
-    width = 80
+    import fcntl
+    import termios
+    import struct
+    ioctl = fcntl.ioctl(0, termios.TIOCGWINSZ,
+                           struct.pack('HHHH', 0, 0, 0, 0))
+    _h, TERMWIDTH, _hp, _wp = struct.unpack('HHHH', ioctl)
+except (ImportError, IOError):
+    TERMWIDTH = None
+
 
 def template_to_file(template_file, dest, **kw):
     with open(dest, 'w') as f:
@@ -123,6 +130,14 @@ def create_module_class_proxy(cls, globals_, locals_):
             else:
                 attr_names.add(methname)
 
+def write_outstream(stream, *text):
+    encoding = getattr(stream, 'encoding', 'ascii') or 'ascii'
+    for t in text:
+        if not isinstance(t, binary_type):
+            t = t.encode(encoding, 'replace')
+        t = t.decode(encoding)
+        stream.write(t)
+
 def coerce_resource_to_filename(fname):
     """Interpret a filename as either a filesystem location or as a package resource.
 
@@ -139,10 +154,10 @@ def status(_statmsg, fn, *arg, **kw):
     msg(_statmsg + "...", False)
     try:
         ret = fn(*arg, **kw)
-        sys.stdout.write("done\n")
+        write_outstream(sys.stdout, "done\n")
         return ret
     except:
-        sys.stdout.write("FAILED\n")
+        write_outstream(sys.stdout, "FAILED\n")
         raise
 
 def err(message):
@@ -163,11 +178,17 @@ def warn(msg):
     warnings.warn(msg)
 
 def msg(msg, newline=True):
-    lines = textwrap.wrap(msg, width)
-    if len(lines) > 1:
-        for line in lines[0:-1]:
-            sys.stdout.write("  " + line + "\n")
-    sys.stdout.write("  " + lines[-1] + ("\n" if newline else ""))
+    if TERMWIDTH is None:
+        write_outstream(sys.stdout, msg)
+        if newline:
+            write_outstream(sys.stdout, "\n")
+    else:
+        # left indent output lines
+        lines = textwrap.wrap(msg, TERMWIDTH)
+        if len(lines) > 1:
+            for line in lines[0:-1]:
+                write_outstream(sys.stdout, "  ", line, "\n")
+        write_outstream(sys.stdout, "  ", lines[-1], ("\n" if newline else ""))
 
 def load_python_file(dir_, filename):
     """Load a file from the given path as a Python module."""
